# QuantumResult

The final output of a quantum EPR simulation. This object contains the diagonalized chi matrix,
participation data from the distributed analysis, and labeled modal data from EigenmodeResults.

::: quansys.simulation.quantum_epr.results.QuantumResults

## Related

- [`QuantumEPR`](quantum_epr.md)